@@ -54,6 +54,10 @@ G_BEGIN_DECLS
  * @f: the #ClutterActorFlags to set
  *
  * Sets the given flags on a #ClutterActor
+ *
+ * Deprecated: 1.24: Changing flags directly is heavily discouraged in
+ *   newly written code. #ClutterActor will take care of setting the
+ *   internal state.
  */
 #define CLUTTER_ACTOR_SET_FLAGS(a,f)    (((ClutterActor*)(a))->flags |= (f))
 
@@ -63,6 +67,10 @@ G_BEGIN_DECLS
  * @f: the #ClutterActorFlags to unset
  *
  * Unsets the given flags on a #ClutterActor
+ *
+ * Deprecated: 1.24: Changing flags directly is heavily discouraged in
+ *   newly written code. #ClutterActor will take care of unsetting the
+ *   internal state.
  */
 #define CLUTTER_ACTOR_UNSET_FLAGS(a,f)  (((ClutterActor*)(a))->flags &= ~(f))
 
@@ -345,6 +353,13 @@ const gchar *                   clutter_actor_get_name
 CLUTTER_AVAILABLE_IN_ALL
 AtkObject *                     clutter_actor_get_accessible                    (ClutterActor                *self);
 
+CLUTTER_AVAILABLE_IN_1_24
+gboolean                        clutter_actor_is_visible                        (ClutterActor                *self);
+CLUTTER_AVAILABLE_IN_1_24
+gboolean                        clutter_actor_is_mapped                         (ClutterActor                *self);
+CLUTTER_AVAILABLE_IN_1_24
+gboolean                        clutter_actor_is_realized                       (ClutterActor                *self);
+
 /* Size negotiation */
 CLUTTER_AVAILABLE_IN_ALL
 void                            clutter_actor_set_request_mode                  (ClutterActor                *self,
