@@ -338,4 +338,18 @@
 # define CLUTTER_AVAILABLE_IN_1_22              _CLUTTER_EXTERN
 #endif
 
+#if CLUTTER_VERSION_MIN_REQUIRED >= CLUTTER_VERSION_1_24
+# define CLUTTER_DEPRECATED_IN_1_24             CLUTTER_DEPRECATED
+# define CLUTTER_DEPRECATED_IN_1_24_FOR(f)      CLUTTER_DEPRECATED_FOR(f)
+#else
+# define CLUTTER_DEPRECATED_IN_1_24             _CLUTTER_EXTERN
+# define CLUTTER_DEPRECATED_IN_1_24_FOR(f)      _CLUTTER_EXTERN
+#endif
+
+#if CLUTTER_VERSION_MAX_ALLOWED < CLUTTER_VERSION_1_24
+# define CLUTTER_AVAILABLE_IN_1_24              CLUTTER_UNAVAILABLE(1, 24)
+#else
+# define CLUTTER_AVAILABLE_IN_1_24              _CLUTTER_EXTERN
+#endif
+
 #endif /* __CLUTTER_MACROS_H__ */
